/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem B. Blind Problem Solving                               */
/*                                                                */
/* Original idea         Maxim Buzdalov                           */
/* Problem statement     Maxim Buzdalov                           */
/* Test set              Maxim Buzdalov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.Writer;
import java.math.BigInteger;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class blind_petr {
	public static void main(String[] args) {
		InputStream inputStream = System.in;
		OutputStream outputStream = System.out;
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		Blind solver = new Blind();
		solver.solve(1, in, out);
		out.close();
	}
}

class Blind {

    public static final String ACCEPT = "accept";
    public static final String STOP = "stop";
    public static final String DECLINE = "decline";

    public void solve(int testNumber, InputReader in, OutputWriter out) {
        int n = in.readInt();
        int c = in.readInt();
        int w = in.readInt();
        out.printLine(ACCEPT);
        out.flush();
        while (w > 0) {
            int nw = in.readInt();
            if (w > nw) {
                out.printLine(ACCEPT);
                out.flush();
                w = nw;
            } else if (w < nw) {
                out.printLine(DECLINE);
                out.flush();
            } else throw new RuntimeException();
        }
        int[] a = new int[n];
        int cnt = 0;
        while (cnt < n) {
            int nw = in.readInt();
            if (nw < w) {
                out.printLine(DECLINE);
                out.flush();
            } else if (nw > w) {
                if (nw <= c && cnt + 1 == n) {
                    out.printLine(STOP);
                    out.flush();
                    return;
                }
                out.printLine(ACCEPT);
                out.flush();
                a[cnt++] = nw - w;
                w = nw;
            } else throw new RuntimeException();
        }
        int best = 0;
        int bestMask = 0;
        for (int curMask = 0; curMask < (1 << n); ++curMask) {
            int cur = 0;
            for (int i = 0; i < n; ++i) if ((curMask & (1 << i)) != 0) cur += a[i];
            if (cur <= c && cur > best) {
                best = cur;
                bestMask = curMask;
            }
        }
        int[] needSub = new int[n];
        for (int i = 0; i < n; ++i)
            if ((bestMask & (1 << i)) == 0)
                needSub[i] = a[i];
        while (true) {
            int nw = in.readInt();
            if (nw == best) {
                out.printLine(STOP);
                out.flush();
                return;
            }
            int delta = w - nw;
            if (delta < 0) {
                out.printLine(DECLINE);
                out.flush();
            } else if (delta > 0) {
                boolean ok = false;
                for (int i = 0; i < n; ++i) if (needSub[i] == delta) {
                    ok = true;
                    needSub[i] = 0;
                    break;
                }
                if (ok) {
                    out.printLine(ACCEPT);
                    out.flush();
                    w = nw;
                } else {
                    out.printLine(DECLINE);
                    out.flush();
                }
            } else throw new RuntimeException();
        }
	}
}

class InputReader {

	private InputStream stream;
	private byte[] buf = new byte[1024];
	private int curChar;
	private int numChars;
	private SpaceCharFilter filter;

	public InputReader(InputStream stream) {
		this.stream = stream;
	}

	public int read() {
		if (numChars == -1)
			throw new InputMismatchException();
		if (curChar >= numChars) {
			curChar = 0;
			try {
				numChars = stream.read(buf);
			} catch (IOException e) {
				throw new InputMismatchException();
			}
			if (numChars <= 0)
				return -1;
		}
		return buf[curChar++];
	}

	public int readInt() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		int sgn = 1;
		if (c == '-') {
			sgn = -1;
			c = read();
		}
		int res = 0;
		do {
			if (c < '0' || c > '9')
				throw new InputMismatchException();
			res *= 10;
			res += c - '0';
			c = read();
		} while (!isSpaceChar(c));
		return res * sgn;
	}

	public boolean isSpaceChar(int c) {
		if (filter != null)
			return filter.isSpaceChar(c);
		return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
	}

	public interface SpaceCharFilter {
		public boolean isSpaceChar(int ch);
	}
}

class OutputWriter {
	private final PrintWriter writer;

	public OutputWriter(OutputStream outputStream) {
		writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
	}

	public OutputWriter(Writer writer) {
		this.writer = new PrintWriter(writer);
	}

	public void print(Object...objects) {
		for (int i = 0; i < objects.length; i++) {
			if (i != 0)
				writer.print(' ');
			writer.print(objects[i]);
		}
	}

	public void printLine(Object...objects) {
		print(objects);
		writer.println();
	}

	public void close() {
		writer.close();
	}

	public void flush() {
		writer.flush();
	}
}


