/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem C. Caravan Robbers                                     */
/*                                                                */
/* Original idea         Egor Kulikov                             */
/* Problem statement     Egor Kulikov                             */
/* Test set              Egor Kulikov                             */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Egor Kulikov                             */
/******************************************************************/

import java.io.*;
import java.util.*;

public class Tests {
    int testNo = 0;
    PrintWriter out;
    static PrintWriter descriptions;
    Random random = new Random(349527983573463L);

    void beginTest(String description, Object... args) {
        ++testNo;
        descriptions.format("%02d: %s\n", testNo, String.format(description, args));
        descriptions.flush();
        try {
            out = new PrintWriter(String.format("tests/%02d", testNo));
        } catch (FileNotFoundException e) {
            throw new AssertionError(e);
        }
    }

    void endTest() {
        out.close();
        assert !out.checkError();
        out = null;
    }

    void writeTest(int count, int[] start, int[] end, String description, boolean shuffle, Object... args) {
		if (shuffle)
			shuffle(count, start, end);
		caravan_kulikov.validateTest(count, start, end);
        beginTest(description, args);
        out.println(count);
		for (int i = 0; i < count; i++)
			out.println(start[i] + " " + end[i]);
        endTest();
    }

    void shuffle(int count, int[] start, int[] end) {
        for (int i = 0; i < count; i++) {
            int j = random.nextInt(i + 1);
            int t = start[i];
            start[i] = start[j];
            start[j] = t;
			t = end[i];
			end[i] = end[j];
			end[j] = t;
        }
    }

    public void run() throws IOException {
        writeTest(3, new int[]{2, 1, 8}, new int[]{6, 4, 12}, "Sample", false);
		writeTest(2, new int[]{0, 1}, new int[]{3, 4}, "Check gcd", false);
		writeTest(1, new int[]{1}, new int[]{2}, "One", false);
		minNonOneAnswer(10);
		minNonOneAnswer(caravan_kulikov.MAXN);
		heuristicFail(20);
		heuristicFail(12345);
		for (int i = 0; i < 3; i++)
			heuristicFail(caravan_kulikov.MAXN / 3);
		for (int i = 0; i < 5; i++)
			bigTest(caravan_kulikov.MAXN - i);
		for (int j = 10; j <= caravan_kulikov.MAXN; j *= 10) {
			for (int i = 0; i < 5; i++)
				randomTest(j);
		}
		closeAnswers();
    }

	private void heuristicFail(int badSegmentSize) {
		int left = random.nextInt(badSegmentSize) + 1;
		int right = random.nextInt(badSegmentSize) + 1;
		int count = badSegmentSize + left + right;
		int[] start = new int[count];
		int[] end = new int[count];
		for (int i = 0; i < left; i++) {
			start[i] = i;
			end[i] = caravan_kulikov.MAXX / 2 + i - left;
		}
		for (int i = 0; i < badSegmentSize; i++) {
			start[i + left] = caravan_kulikov.MAXX / 2 - badSegmentSize + i;
			end[i + left] = caravan_kulikov.MAXX / 2 + i;
		}
		for (int i = 0; i < right; i++) {
			start[i + left + badSegmentSize] = caravan_kulikov.MAXX / 2 + i;
			end[i + left + badSegmentSize] = caravan_kulikov.MAXX - right + i + 1;
		}
		writeTest(count, start, end, "Heuristic fail " + badSegmentSize, true);
	}

	private void bigTest(int count) {
		int max = caravan_kulikov.MAXX;
		while (caravan_kulikov.gcd(max, count) != 1)
			max--;
		int[] start = new int[count];
		int[] end = new int[count];
		for (int i = 0; i < count; i++) {
			start[i] = i;
			end[i] = max - count + 1 + i;
		}
		writeTest(count, start, end, "Big test", true);
	}

	private void randomTest(int count) {
		int[] all = new int[2 * count];
		Set<Integer> was = new HashSet<Integer>();
		for (int i = 0; i < 2 * count; i++) {
			while (true) {
				int next = random.nextInt(caravan_kulikov.MAXX + 1);
				if (!was.contains(next)) {
					was.add(next);
					all[i] = next;
					break;
				}
			}
		}
		Arrays.sort(all);
		int[] start = new int[count];
		int[] end = new int[count];
		int j = 0;
		int k = 0;
		for (int i = 0; i < 2 * count; i++) {
			if (j == k)
				start[j++] = all[i];
			else if (j == count)
				end[k++] = all[i];
			else if (random.nextBoolean())
				start[j++] = all[i];
			else if (j != k + 1 || all[i] - start[k] != 1)
				end[k++] = all[i];
			else
				start[j++] = all[i];
		}
		writeTest(count, start, end, "Random test " + count, true);
	}

	private void closeAnswers() {
		int max = (caravan_kulikov.MAXN + 1) / 2;
		int min = max - 1;
		int[] start = new int[max + min];
		int[] end = new int[max + min];
		for (int i = 0; i < max; i++) {
			start[i] = i;
			end[i] = i + 2;
		}
		for (int i = 0; i < min; i++) {
			start[i + max] = caravan_kulikov.MAXX / 2 + i;
			end[i + max] = caravan_kulikov.MAXX / 2 + i + 2;
		}
		writeTest(min + max, start, end, "Close answers", true);
	}

	private void minNonOneAnswer(int count) {
		int[] start = new int[count];
		int[] end = new int[count];
		for (int i = 0; i < count; i++) {
			start[i] = i;
			end[i] = i + 2;
		}
		writeTest(count, start, end, "Min non-1 answer " + count, true);
	}

	public static void main(String[] args) throws IOException {
        new File("tests").mkdir();
        descriptions = new PrintWriter("tests/tests.lst");
        new Tests().run();
        descriptions.close();
    }
}

