/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem D. Disjoint Regular Expressions                        */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Andrey Stankevich                        */
/* Test set              Andrey Stankevich                        */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Andrey Stankevich                        */
/******************************************************************/

import java.io.*;
import java.util.*;

public class Tests {
    private static int nTests = 0;
    private static final Random rnd = new Random(81278197123947L);
    private static final File root = new File("tests");
    private static final File lst = new File(root, "tests.lst");

    public void write(String re1, String re2) {
    	System.out.format("write test #%d\n", nTests + 1);
        try {
            PrintWriter out = new PrintWriter(new File(root, String.format("%02d", ++nTests)));
            out.println(re1);
            out.println(re2);
            out.close();
        } catch (IOException ex) {
            throw new RuntimeException(ex);
        }
    }

    void writeBigAns1() {
        String re1 = "(";
        for (int i = 0; i < 96; i++) {
            re1 += "a";
        }
        re1 += "b";
        re1 += ")*";
        String re2 = "";
        for (int i = 0; i < 33; i++) {
            re2 += "a*b";
        }
        write(re1, re2);
    }

    void writeBigAns2() {
        String re1 = "a(";
        for (int i = 0; i < 96; i++) {
            re1 += "a";
        }
        re1 += ")*";
        String re2 = "(";
        for (int i = 0; i < 95; i++) {
            re2 += "a";
        }
        re2 += ")*";
        write(re1, re2);
    }

    String randomString(int len, int cn) {
        StringBuilder r = new StringBuilder();
        for (int i = 0; i < len; i++) {
            r.append((char) (rnd.nextInt(cn) + 'a'));
        }
        return r.toString();
    }

    String[] randomSplit(String s, int minL, int pn, String[] differFrom) {
        String src = s;
        int retries = 0;
        do {
            s = src;
            ArrayList<String> res = new ArrayList<>();
            for (int i = 0; i < pn; i++) {
                int len;
                do {
                    if (i == pn - 1) {
                        len = s.length();
                    } else {
                        len = rnd.nextInt(2 * s.length() / (pn - i));
                    }
                } while (len < minL || (s.length() - len < minL * (pn - i - 1)));
                res.add(s.substring(0, len));
                s = s.substring(len);
            }
            boolean ok = true;
            if (differFrom != null) {
                check:
                for (String z : res) {
                    for (String y : differFrom) {
                        if (z.equals(y)) {
                            ok = false;
                            break check;
                        }
                    }
                }
            }
            if (ok) {
                return res.toArray(new String[res.size()]);
            } else {
                retries++;
                if (retries > 1000) {
                    return null;
                }
            }
        } while (true);
    }

    String arr2re(String[] s) {
        String res = "(";
        for (int i = 0; i < s.length; i++) {
            res = res + s[i];
            if (i < s.length - 1) {
                res += "|";
            }
        }
        res = res + ")*";
        return res;
    }

    String arr2re2(String[][] s) {
        String res = "(";
        for (int i = 0; i < s.length; i++) {
            res = res + "(";
            for (int j = 0; j < s[i].length; j++) {
                res = res + s[i][j];
                if (j < s[i].length - 1) {
                    res = res + "|";
                }
            }
            res = res + ")*";
            if (i < s.length - 1) {
                res += "|";
            }
        }
        res = res + ")*";
        return res;
    }

    void gen2Split(int len, int pn, int cn) {
        System.out.println("Generating 2 split regexp (" + pn  + ")@" + cn + ", it can take a long time please wait...");
        disjoint_as sol = new disjoint_as();
        String re1, re2;
        String s;
        do {
            s = randomString(len - (pn - 1) - 3, cn);

            String[] s1 = randomSplit(s, 1, pn, null);
            String[] s2 = randomSplit(s, 1, pn, s1);
            if (s1 != null && s2 != null) {
                re1 = arr2re(s1);
                re2 = arr2re(s2);
            } else {
                re1 = "a";
                re2 = "a";
            }
        } while (sol.solve(re1, re2).length() < s.length() / 2);
        write(re1, re2);
    }

    void gen2LayerSplit(int len, int pn, int qn, int cn, int reqL) {
        System.out.println("Generating 2 level regexp (" + pn + "x" + qn + ")@" + cn + ", it can take a long time please wait...");
        disjoint_as sol = new disjoint_as();
        String re1 = "a", re2 = "a";
        String s, z = "";
        search:
        do {
            ArrayList<String> diffFrom = new ArrayList<>();
            s = randomString(len - (pn - 1) - 3 - pn * (3 + qn - 1), cn);

            String[] s1 = randomSplit(s, qn, pn, null);
            if (s1 == null) {
                continue search;
            }
            String[][] z1 = new String[s1.length][];
            for (int i = 0; i < s1.length; i++) {
                z1[i] = randomSplit(s1[i], 1, qn, diffFrom.toArray(new String[diffFrom.size()]));
                if (z1[i] == null) {
                    continue search;
                }
                for (int j = 0; j < z1[i].length; j++) {
                    diffFrom.add(z1[i][j]);
                }
            }
            String[] s2 = randomSplit(s, qn, pn, s1);
            if (s2 == null) {
                continue search;
            }
            String[][] z2 = new String[s2.length][];
            for (int i = 0; i < s2.length; i++) {
                z2[i] = randomSplit(s2[i], 1, qn, diffFrom.toArray(new String[diffFrom.size()]));
                if (z2[i] == null) {
                    continue search;
                }
                for (int j = 0; j < z1[i].length; j++) {
                    diffFrom.add(z2[i][j]);
                }
            }

            re1 = arr2re2(z1);
            re2 = arr2re2(z2);
            z = sol.solve(re1, re2);
//            System.out.println(re1 + " " + re2 + " " + z + " " + s);
        } while (z.length() < s.length() * reqL / 100);
        System.out.println(re1 + " " + re2);
        write(re1, re2);
        System.out.println("Done");
    }

    String genRec(String a, String b, int d) {
        if (d == 0) {
            return a;
        } else {
            return "(" + genRec(a, b, d - 1) + ")*" + b;
        }
    }

    String genRec2(String a, String b, int d) {
        if (d == 0) {
            return a;
        } else {
            return "(" + genRec2(a, b, d - 1) + ")*|" + b;
        }
    }

    String dup(String a, int n) {
        String r = "";
        for (int i = 0; i < n; i++) {
            r += a;
        }
        return r;
    }

    public void run() {
        if (!root.exists()) {
            root.mkdir();
        }

        write("a(ab)*b", "a(a|b)*ab");
        write("a(ab)*a", "a(a|b)*ba");

        // Check or
        write("a|b", "a|c");
        write("a|bc", "ac|b");
        write("a|b|c", "c|d|e");
        write("a|b|c", "d|e|f");
        write("a|b|c", "d|c|e");
        write("ab|bc|cd", "ce|cd|cc");
        write("ab|bc|cd", "ce|cf|cg");
        write("(a|b|c)(d|e|f)", "ac|bd|ef");
        write("(a|b|c)(d|e|f)", "ab|bc|ef");

        // Check concatenation
        write("b*a*", "ab");
        write("b*a*", "a");
        write("b*a*", "b");
        write("a*b*", "b*a*");

        // Check Kleene
        write("abab", "ab(ab)*ab");
        write("ababab", "ab(ab)*ab");
        write("abababab", "ab(ab)*ab");
        write("ababababab", "ab(ab)*ab");
        write("ababababab", "ab(a|b)*ab");
        write("(cb*)*", "b");
        write("(a*c)*", "a");
        write("(a*cb*)*", "ab");
        write("(a*cb*)*", "ba");

        write("a**", "a*");
        write("a***************************************************************************************************", 
              "a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*a*");

        // Check empty
        write("a*", "a*");
        write("a*", "b*");
        write("(a|b)*", "(b|c)*");
        write("(a|b|c)*", "(d|e|f)*");
        write("(a|b)*", "(ab)*");
        write("(ab)*", "(ba)*");

        // Check shortest
        write("aa|b", "aa|b");
        write("aa|b", "(a|b)*");
        write("(aa|b)*", "(a|ab|b)*");

        // Check correct bfs
        write("(a|b*b*b*b*b*b*b*b*b*b*b*)c", "(a|b)*c");
        write("(a|b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*)c", "(a|b)*c");
        write("(aaaaaaaaaaaaaaaaaaa|b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*)c", "(a|b)*c");
        write("(a|b*b*b*b*b*b*)(a|b*b*b*b*b*b*)(a|b*b*b*b*b*b*)c(a|b*b*b*b*b*b*)(a|b*b*b*b*b*b*)(a|b*b*b*b*b*b*)", "(a|b)*c(a|b)*");

        // Check recursion ok
        write(genRec("a", "b", 20), dup("(a|b)", 20));
        write(genRec2("a", "b", 19), dup("(a|b)", 19));
        write(genRec2("a", "b", 19), dup("a", 100));

        String allOr = "a";
        for (int z = 1; z < 26; z++) {
            allOr += "|" + (char) ('a' + z);
        }
        String allConcat = "a";
        for (int z = 1; z < 26; z++) {
            allConcat += (char) ('a' + z);
        }
        write(allOr, allOr);
        write(allOr, allConcat);
        write(allConcat, allConcat);
        write("(" + allOr + ")*", allConcat);
        write("a(" + allOr + ")*", "(" + allConcat + ")*");

        // Big ans
        writeBigAns1();
        writeBigAns2();

        // Seems to have the maximum possible answer size (9312).
        write("(aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa)*",
              "(aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa)*");
        // Same idea, but more stars
        write("(aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa)*******",
              "(aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa)********");
        // Seems to have maximum possible reachable states in the intersection FSM (findPath calls in _gk).
        write("b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*",
                "b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*b*a");

        // Different GA generated tests for reasonably big answers.
        write("((b|a)b(b|a)bb(b|a)b(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b(b|a)b(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b)*", "((b|a)b(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b(b|a)b(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b)*");
        write("((b|a)bb(b|a)bb(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b)*", "((b|a)bb(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b(b|a)bb(b|a)b(b|a)b)*");
        write("((b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa)*", "b|((b|a)aa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa(b|a)aaaa)*");
        write("(aaaa(aa|aa)aa(aa|aa)aaaa(aa|aa)aaaa(aa|aa)aa(aa|aa)aaaa(aa|aa)aaaa(aa|aa)aa(aa|aa)aaaa(aa|aa)a)*", "(aa(aa|aa)aaaa(aa|aa)aa(aa|aa)aaaa(aa|aa)aaaa(aa|aa)aa(aa|aa)aaaa(aa|aa)aaaa(aa|aa)aa(aa|aa))*");
        write("(aa(b|aa)aa(b|aa)aaaaa(b|aa)aa(b|aa)aaaaa(b|aa)aa(b|aa)aaaa(b|aa)aa(b|aa)aaaaa(b|aa)aa(b|aa)aa)*", "aa(b|aa)aa(b|aa)aa|(aa(b|aa)aa(b|aa)aaaaa(b|aa)aa(b|aa)aaaa(b|aa)aa(b|aa)aaaaa(b|aa)aa(b|aa)aa)*");
        write("(bbbbbbbb(b|a)bbbbbbbb(b|a)bbbb(b|a)bbbbbbbb(b|a)bbbbbbbb(b|a)bbbbbbbb(b|a)bbbbbbbb(b|a)bbbb(b|a))*", "(bbbbbbbb(b|a)bbbbbbbb(b|a)bbbb(b|a)bbbbbbbb(b|a)bbbbbbbb(b|a))*");
        write("((b|a)bb(b|a)bb(b|a)(b|a)bb(b|a)(b|a)bb(b|a)bb(b|a)(b|a)bb(b|a)(b|a)bb(b|a)bb(b|a)(b|a)bb(b|a))*", "((b|a)bb(b|a)bb(b|a)(b|a)bb(b|a)(b|a)bb(b|a)bb(b|a)(b|a)bb(b|a)(b|a)bb(b|a)bb(b|a))*");
        write("(bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a)bbbb(b|a))*", "(bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a))*");
        write("(bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a))*", "(bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a)bbbb(b|a)bbbb(b|a)bb(b|a))*");
        write("((a|b)bbbbbbbbbbbb(a|b)bbbbbbbbbbbb(a|b)bbbbbbbbbbbb(a|b))*", "((a|b)bbbbbbbbbbbb(a|b)bbbbbbbbbbbb(a|b)bbbbbbbbbbbb(a|b)(a|b)bbbbbbbbbbbb)*|(a|b)bbbbbbbbbbbb(a|b)");
        write("((bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb)*", "((bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb(bb|bb)bbbb)*");
        write("(bbbbbbbbb(bb|bb)bbbb(bb|bb)bbbbbbbbbbbb(bb|bb)bbbb(bb|bb)bbbbbbbbbbbbb(bb|bb)bbbb(bb|bb)bbbb)*", "(bbbbbbbb(bb|bb)bbbb(bb|bb)bbbbbbbbbbbbb(bb|bb)bbbb(bb|bb)bbbb)*");
        write("(baba(baba|baba)babaa*baba(baba|baba)babaa*baba(baba|baba)babaa*baba(baba|baba)babaa*)*", "(bababa(baba|baba)babaa*baba(baba|baba)babaa*baba(baba|baba)babaa*baba(baba|baba)babaa*)*");
        write("(aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*(ab*|a))*", "(aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*aab*)*");
        write("((a|a)b*aaaaaaaab*aaaab*aaaaaaaab*aaaa(a|a)b*aaaaaaaab*aaaab*aaaaaaaab*aaaa)*", "(b*aaaaaaaab*aaaab*aaaaaaaab*aaaa(a|a)b*aaaaaaaab*aaaab*aaaaaaaab*aaaa)*");

        gen2Split(100, 5, 2);
        gen2Split(100, 5, 5);
        gen2Split(100, 5, 20);
        gen2Split(100, 10, 2);
        gen2Split(100, 10, 5);
        gen2Split(100, 10, 20);

        gen2LayerSplit(100, 3, 3, 2, 50);
        gen2LayerSplit(100, 3, 3, 3, 60);
        gen2LayerSplit(100, 3, 3, 5, 80);
        gen2LayerSplit(100, 3, 3, 10, 100);
        gen2LayerSplit(100, 4, 4, 20, 60);
        gen2LayerSplit(100, 4, 4, 26, 90);
    }

    public static void main(String[] args) {
        new Tests().run();
    }
}

