/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem D. Disjoint Regular Expressions                        */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Andrey Stankevich                        */
/* Test set              Andrey Stankevich                        */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Andrey Stankevich                        */
/******************************************************************/

import java.util.*;
import java.io.*;

public class disjoint_as {
    FastScanner in;
    PrintWriter out;

    public void solve() throws IOException {
        String s = in.next();
        String t = in.next();
        
        String res = solve(s, t);
        if (!res.equals("")) {
            out.println("Wrong");
            out.println(res);
        } else {
            out.println("Correct");
        }
    }
    
    String solve(String s, String t) {
        Auto sa = convert(s);
        Auto ta = convert(t);

        Auto isect = multiply(sa, ta);
        if (bfs(isect, 0)) {
            return ans;
        } else {
            return "";
        }
    }
    
    String ans;
    
    boolean bfs(Auto a, int x) {
        int[] q = new int[4 * a.n];
        int[] from = new int[4 * a.n];
        char[] by = new char[4 * a.n];
        int h = 2 * a.n;
        int t = 2 * a.n + 1;
        q[h] = x;

        boolean[] u = new boolean[2 * a.n];
        u[x] = true;

        while (h < t) {
            int y = q[h++];
            boolean has = y >= a.n;
            for (int c = 0; c < 26; c++) {
                int z = a.n + a.go[y % a.n][c];
                if (z != -1 && !u[z]) {
                    q[t++] = z;
                    from[z] = y;
                    by[z] = (char) ('a' + c);
                    u[z] = true;
                }
            }
            for (int v : a.eps[y % a.n]) {
                int z = v + (has ? a.n : 0);
                if (!u[z]) {
                    q[--h] = z;
                    from[z] = y;
                    by[z] = 0;
                    u[z] = true;
                }
            }
        }
        
        if (!u[2 * a.n - 1]) {
            return false;
        }
        
        int v = 2 * a.n - 1;
        ans = "";
        while (v > 0) {
            if (by[v] != 0) {
                ans = by[v] + ans;
            }
            v = from[v];
        }
        return true;
    }
    
    Auto convert(String re) {
        str = re + "$";
        p = 0;
        nextToken();
        Node tree = expr();
        assert token == Token.END; 
        
        return buildAuto(tree);
    }
    
    Auto multiply(Auto a, Auto b) {
        Auto r = new Auto(a.n * b.n);
        for (int i = 0; i < a.n; i++) {
            for (int j = 0; j < b.n; j++) {
                for (int c = 0; c < 26; c++) {
                    int z = a.go[i][c];
                    int y = b.go[j][c];
                    if (z != -1 && y != -1) {
                        r.go[i * b.n + j][c] = z * b.n + y;
                    }
                    
                }
                for (int z : a.eps[i]) {
                    for (int y : b.eps[j]) {
                        r.eps[i * b.n + j].add(z * b.n + y);
                    }
                    r.eps[i * b.n + j].add(z * b.n + j);
                }
                for (int y : b.eps[j]) {
                    r.eps[i * b.n + j].add(i * b.n + y);
                }
            }
        }
        return r;
    }
    
    Auto buildAuto(Node t) {
        switch (t.op) {
            case TERM: {
                Auto res = new Auto(2);
                res.go[0][t.c - 'a'] = 1;
                return res;
            }
            case CONCAT: {
                Auto ra = buildAuto(t.a);
                Auto rb = buildAuto(t.b);
                Auto res = new Auto(ra.n + rb.n);
                for (int i = 0; i < ra.n; i++) {
                    for (int j = 0; j < 26; j++) {
                        res.go[i][j] = ra.go[i][j];
                    }
                    res.eps[i] = ra.eps[i];
                }
                for (int i = 0; i < rb.n; i++) {
                    for (int j = 0; j < 26; j++) {
                        int z = rb.go[i][j];
                        if (z != -1) {
                            res.go[ra.n + i][j] = z + ra.n;
                        }
                    }
                    for (int z : rb.eps[i]) {
                        res.eps[ra.n + i].add(z + ra.n);
                    }
                }
                res.eps[ra.n - 1].add(ra.n);
                return res;
            }
            case UNION: {
                Auto ra = buildAuto(t.a);
                Auto rb = buildAuto(t.b);
                Auto res = new Auto(ra.n + rb.n + 2);
                for (int i = 0; i < ra.n; i++) {
                    for (int j = 0; j < 26; j++) {
                        int z = ra.go[i][j];
                        if (z != -1) {
                            res.go[i + 1][j] = z + 1;
                        }
                    }
                    for (int z : ra.eps[i]) {
                        res.eps[i + 1].add(z + 1);
                    }
                }
                for (int i = 0; i < rb.n; i++) {
                    for (int j = 0; j < 26; j++) {
                        int z = rb.go[i][j];
                        if (z != -1) {
                            res.go[ra.n + 1 + i][j] = z + 1 + ra.n;
                        }
                    }
                    for (int z : rb.eps[i]) {
                        res.eps[i + ra.n + 1].add(z + ra.n + 1);
                    }
                }
                res.eps[0].add(1);
                res.eps[0].add(ra.n + 1);
                res.eps[ra.n].add(ra.n + rb.n + 1);
                res.eps[ra.n + rb.n].add(ra.n + rb.n + 1);
                return res;
            }
            case KLEENE: {
                Auto ra = buildAuto(t.a);
                Auto res = new Auto(ra.n + 2);
                for (int i = 0; i < ra.n; i++) {
                    for (int j = 0; j < 26; j++) {
                        int z = ra.go[i][j];
                        if (z != -1) {
                            res.go[i + 1][j] = z + 1;
                        }
                    }
                    for (int z : ra.eps[i]) {
                        res.eps[i + 1].add(z + 1);
                    }
                }
                res.eps[0].add(1);
                res.eps[0].add(ra.n + 1);
                res.eps[ra.n].add(ra.n + 1);
                res.eps[ra.n + 1].add(0);
                return res;
            }
        }
        return null;
    }
    
    class Auto {
        int n;
        int go[][];
        Set<Integer> eps[];

        Auto(int n) {
            this.n = n;
            go = new int[n][26];
            for (int[] z : go) {
                Arrays.fill(z, -1);
            }
            eps = new Set[n];
            for (int i = 0; i < n; i++) {
                eps[i] = new HashSet<Integer>();
            }
        }
    }

    Node expr() {
        Node t = term();
        while (token == Token.OR) {
            nextToken();
            Node r = term();
            t = new Node(Operation.UNION, t, r);
        }
        return t;
    }
    
    Node term() {
        Node t = star();
        while (token == Token.C || token == Token.LP) {
            Node r = star();
            t = new Node(Operation.CONCAT, t, r);
        }
        return t;
    }
    
    Node star() {
        Node r;
        if (token == Token.C) {
            r = new Node(curc);
            nextToken();
        } else if (token == Token.LP) {
            nextToken();
            r = expr();
            assert token == Token.RP;
            nextToken();
        } else {
            throw new AssertionError();
        }
        if (token == Token.STAR) {
            r = new Node(Operation.KLEENE, r, null);
            while (token == Token.STAR) {
                nextToken();
            }
        }
        return r;
    }
    
    Token token;
    String str;
    char curc;
    int p;
    
    void nextToken() {
        switch (str.charAt(p)) {
            case '(':
                token = Token.LP;
                p++;
                break;
            case ')':
                token = Token.RP;
                p++;
                break;
            case '|':
                token = Token.OR;
                p++;
                break;
            case '*':
                token = Token.STAR;
                p++;
                break;
            case '$':
                token = Token.END;
                p++;
                break;
            default:
                token = Token.C;
                curc = str.charAt(p);
                p++;
        }
    }
    
    enum Token {
        C, LP, RP, STAR, OR, END
    }

    public void run() {
        try {
            in = new FastScanner(new File("disjoint.in"));
            out = new PrintWriter(new File("disjoint.out"));

            solve();

            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    enum Operation {
        TERM, UNION, CONCAT, KLEENE
    }
    
    class Node {
        Operation op;
        Node a, b;
        char c;

        Node(Operation op, Node a, Node b) {
            this.op = op;
            this.a = a;
            this.b = b;
        }

        Node(char c) {
            op = Operation.TERM;
            this.c = c;
        }
    }

    public static void main(String[] arg) {
        new disjoint_as().run();
    }

    static class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        FastScanner(File file) throws IOException {
            br = new BufferedReader(new FileReader(file));
        }

        String next() {
            while (st == null || !st.hasMoreTokens()) {
                try {
                    st = new StringTokenizer(br.readLine());
                } catch (IOException e) {
                    e.printStackTrace();
                    return "";
                }
            }
            return st.nextToken();
        }

        int nextInt() {
            return Integer.parseInt(next());
        }
    }
}
