/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem E. Exact Measurement                                   */
/*                                                                */
/* Original idea         Pavel Mavrin                             */
/* Problem statement     Pavel Mavrin                             */
/* Test set              Pavel Mavrin                             */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Pavel Mavrin                             */
/******************************************************************/

import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.PriorityQueue;
import java.util.StringTokenizer;

public class exact_pm {

    private BufferedReader br;
    private StringTokenizer st;
    private PrintWriter out;

    String next() throws IOException {
        while (st == null || !st.hasMoreTokens()) {
            st = new StringTokenizer(br.readLine());
        }
        return st.nextToken();
    }

    int nextInt() throws IOException {
        return Integer.parseInt(next());
    }

    private long nextLong() throws IOException {
        return Long.parseLong(next());
    }

    public static void main(String[] args) {
        new exact_pm().run();
    }

    private void run() {
        try {
            br = new BufferedReader(new FileReader("exact.in"));
            out = new PrintWriter("exact.out");
            solve();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    private void solve() throws IOException {
        long x = nextLong();
        int n = nextInt();
        List<Box>[] boxes = new List[19];
        for (int i = 0; i < 19; i++) {
            boxes[i] = new ArrayList<Box>();
        }
        for (int i = 0; i < n; i++) {
            Box box = new Box(i, nextInt(), nextLong());
            boxes[box.k].add(box);
        }

        long[] nearest = new long[19];
        long z = 1;
        for (int i = 0; i < 19; i++) {
            nearest[i] = (x / z) * z;
            z *= 10;
        }

        int cur = 0;

        PriorityQueue<Box> heap = new PriorityQueue<Box>(n);
        long sum = 0;

        List<Box> res = new ArrayList<Box>();

        while (sum < x) {
            while (cur < 19 && x - sum <= nearest[cur]) {
                heap.addAll(boxes[cur]);
                cur++;
            }
            if (heap.isEmpty()) {
                out.println(-1);
                return;
            }
            Box longest = heap.remove();
            sum += longest.s;
            res.add(longest);
//            if (res.size() % 100 == 0) System.out.println(res.size() + " " + sum);
        }

        out.println(res.size());
        for (int i = 0; i < res.size(); i++) {
            Box box = res.get(i);
            out.print(box.id + 1);
            if (i == res.size() - 1) {
                out.println();
            } else {
                out.print(" ");
            }
        }
    }

    class Box implements Comparable<Box> {
        int id;
        int k;
        long q;
        long s;

        Box(int id, int k, long q) {
            this.id = id;
            this.k = k;
            this.q = q;
            s = q;
            for (int i = 0; i < k; i++) {
                s *= 10;
            }
        }

        @Override
        public int compareTo(Box o) {
            return -Long.compare(s, o.s);
        }
    }

}

