/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem J. Jumping Around                                      */
/*                                                                */
/* Original idea         Andrey Stankevich                        */
/* Problem statement     Andrey Stankevich                        */
/* Test set              Andrey Stankevich                        */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Andrey Stankevich                        */
/******************************************************************/

import java.io.*;
import java.util.*;

public class Tests {
    private static int nTests = 0;
    private static final Random rnd = new Random(81278197123947L);
    private static final File root = new File("tests");
    private static final File lst = new File(root, "tests.lst");

    public void write(Collection<int[]> tests) {
        try {
            PrintWriter out = new PrintWriter(new File(root, String.format("%02d", ++nTests)));
            out.println(tests.size());
            for (int[] z : tests) {
                out.println(z[0] + " " + z[1] + " " + z[2]);
            }
            out.close();
        } catch (IOException ex) {
            throw new RuntimeException(ex);
        }
    }

    void writeSmall() {
        ArrayList<int[]> test = new ArrayList<int[]>();
        for (int i = 3; i <= 10; i++) {
            for (int j = 3; j <= 10; j++) {
                for (int k = 3; k <= 10; k++) {
                    test.add(new int[]{i, j, k});
                    if (test.size() == 20) {
                        write(test);
                        test = new ArrayList<int[]>();
                    }
                }
            }
        }
        if (test.size() > 0) {
            write(test);
        }
    }

    void writeBig() {
        ArrayList<int[]> test = new ArrayList<int[]>();
        int[] z = {3, 4, 5, 4998, 4999, 5000};
        for (int i : z) {
            for (int j : z) {
                for (int k : z) {
                    test.add(new int[]{i, j, k});
                    if (test.size() == 20) {
                        write(test);
                        test = new ArrayList<int[]>();
                    }
                }
            }
        }
        if (test.size() > 0) {
            write(test);
        }
    }

    void writeRandom() {
        ArrayList<int[]> test = new ArrayList<int[]>();
        for (int i = 0; i < 100; i++) {
            test.add(new int[]{rnd.nextInt(4998) + 3, rnd.nextInt(4998) + 3, rnd.nextInt(4998) + 3});
            if (test.size() == 20) {
                write(test);
                test = new ArrayList<int[]>();
            }
        }
        if (test.size() > 0) {
            write(test);
        }
    }

    void writeRandomSkew() {
        ArrayList<int[]> test = new ArrayList<int[]>();
        for (int i = 0; i < 100; i++) {
            int a = rnd.nextBoolean() ? 3 + rnd.nextInt(100) : 5000 - rnd.nextInt(100);
            int b = rnd.nextBoolean() ? 3 + rnd.nextInt(100) : 5000 - rnd.nextInt(100);
            int c = rnd.nextBoolean() ? 3 + rnd.nextInt(100) : 5000 - rnd.nextInt(100);
            test.add(new int[]{a, b, c});
            if (test.size() == 20) {
                write(test);
                test = new ArrayList<int[]>();
            }
        }
        if (test.size() > 0) {
            write(test);
        }
    }

    public void run() {
        if (!root.exists()) {
            root.mkdir();
        }

        write(Arrays.asList(new int[][]{
                {3, 3, 3},
                {3, 4, 3}
        }));
        
        writeSmall();
        writeBig();
        writeRandom();
        writeRandomSkew();
    }

    public static void main(String[] args) {
        new Tests().run();
    }
}

